/*
 *  test-libvideogfx.cc
 */

#include "config.h"
#include "../libvideogfx/libvideogfx.hh"

#include <iostream>
using namespace std;
using namespace videogfx;


int
main (int   argc,
      char *argv[])
{
  cout << "\nNot written yet ;-)\n\n";

  return 0;
}
